@@ -10,7 +10,7 @@ require Exporter;
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw();
-our $VERSION   = '0.02';
+our $VERSION   = '0.03';
 
 sub new{
 	my $class = shift;
@@ -185,7 +185,7 @@ Deliver image to client and set the encrypted cookie:
   print $image_data;
   exit;
 
-See the sample B<slcaptcha> CGI script in the distribution.
+See the sample B<slcapapp> CGI script in the distribution.
 
 =head2 CAPTCHA KEY FILE
 
@@ -195,7 +195,7 @@ For the key, save 16 random bytes in any file readable by the web server:
 
 =head2 CAPTCHA INTEGRATION
 
-Fixme: Sample HTML
+See the sample B<slcapapp> CGI script in the distribution.
 
 =head2 CAPTCHA VALIDATION
 
@@ -258,7 +258,6 @@ Takes the HTTP cookie returned from the client (after completion of the
 Captcha quiz), decrypts it, checks for the correct content and whether it 
 is still valid, and compares it to the value entered on the client.
 
-  my $ = $slcaptcha->encrypt($random_number);
   my $captchavalid = Captcha::Stateless->validate(
     cookie  => $q->cookie('slcaptcha'),
     entered => $q->param('captcha-entered')
@@ -266,6 +265,10 @@ is still valid, and compares it to the value entered on the client.
 
 Returns 1 on success, 0 on validation failure.
 
+=head1 STATUS
+
+Development
+
 =head1 BUGS & SUGGESTIONS
 
 No known bugs. 
@@ -274,6 +277,9 @@ Very open to review and maybe ports of the core concept to other languages.
 
 =head1 LIMITATIONS
 
+Captchas, once solved, can be used repeatedly until they expire. Needs 
+to be worked around on an application basis.
+
 No scalability tests have been conducted. 
 
 No security review has been conducted. The author may be completely deluded
